Every diagnostic check function returns an object of class
"rcisignal_diag_result". This constructor is the single source of
truth for the result shape.
Usage
rcisignal_diag_result(status, label, detail, data = list())Every diagnostic check function returns an object of class
"rcisignal_diag_result". This constructor is the single source of
truth for the result shape.
rcisignal_diag_result(status, label, detail, data = list())